@@ -1,5 +1,5 @@
 package Net::Whois::Raw::Data;
-$Net::Whois::Raw::Data::VERSION = '2.96';
+$Net::Whois::Raw::Data::VERSION = '2.99';
 # ABSTRACT: Config for Net::Whois::Raw.
 
 use utf8;
@@ -14,6 +14,9 @@ our @www_whois = qw(
 
 our %servers = qw(
     RU                  whois.ripn.net
+    NET.RU              whois.ripn.net
+    ORG.RU              whois.ripn.net
+    PP.RU               whois.ripn.net
     SU                  whois.ripn.net
     XN--P1AI            whois.ripn.net
     XN--D1ACJ3B         whois.ripn.net
@@ -23,9 +26,6 @@ our %servers = qw(
     XN--80ADXHKS        whois.nic.xn--80adxhks
     XN--P1ACF           whois.nic.xn--p1acf
 
-    NET.RU              whois.nic.ru
-    ORG.RU              whois.nic.ru
-    PP.RU               whois.nic.ru
     INT.RU              whois.int.ru
 
     RU.NET              whois.flexireg.net
@@ -219,6 +219,7 @@ our %servers = qw(
     GRAPHICS        whois.donuts.co
     GRATIS          whois.donuts.co
     GRIPE           whois.donuts.co
+    GROUP           whois.donuts.co
     GUIDE           whois.donuts.co
     GURU            whois.donuts.co
     HOLDINGS        whois.donuts.co
@@ -387,6 +388,7 @@ our %servers = qw(
     NRW             whois-dub.mm-registry.com
     SURF            whois-dub.mm-registry.com
     WEDDING         whois-dub.mm-registry.com
+    VIP             whois-dub.mm-registry.com
     WORK            whois-dub.mm-registry.com
     YOGA            whois-dub.mm-registry.com
 
@@ -763,12 +765,14 @@ our %servers = qw(
     SECURITY    whois.centralnic.com
     SITE        whois.centralnic.com
     SPACE       whois.centralnic.com
+    STORE       whois.centralnic.com
     TECH        whois.centralnic.com
     THEATRE     whois.centralnic.com
     TICKETS     whois.centralnic.com
     WEBSITE     whois.centralnic.com
     WIKI        whois.centralnic.com
     XYZ         whois.centralnic.com
+    TUBE        whois.nic.tube
 
     ORG.NS      whois.pir.org
     BIZ.NS      whois.biz
@@ -2691,7 +2695,7 @@ Net::Whois::Raw::Data - Config for Net::Whois::Raw.
 
 =head1 VERSION
 
-version 2.96
+version 2.99
 
 =head1 AUTHOR
 
